@@ -33,12 +33,14 @@ class Pg:
  
         return content
 
+    async def ncfetch(self):
+        content = await self.pool.fetchrow(f"SELECT * FROM {self.table}")
+ 
+        return content
+
     async def fetch(self, **opt):
         "テーブルの最初のデータを取得する"
 
-        if opt is None:
-            content = await self.pool.fetchrow(f"SELECT * FROM {self.table}")
-
         enums = enumerate(opt.keys(), 1)
         content = await self.pool.fetchrow(f"SELECT * FROM {self.table} WHERE {' AND '.join(f'{c} = ${i}' for i, c in enums)}", *opt.values())
         return content
@@ -96,6 +98,9 @@ class Pg:
         enums = enumerate(opt.keys(), 1)
         key=' AND '.join(f'{c} = ${i}' for i, c in enums if i !=1)
 
+        if not key:
+            return await self.pool.execute(f"UPDATE {self.table} SET {one_column}", *opt.values())
+
         await self.pool.execute(f"UPDATE {self.table} SET {one_column} WHERE {key}", *opt.values())
     
 
@@ -104,16 +109,19 @@ class Pg:
 
         enums = enumerate(opt.keys(), 1)
 
+            
+
         await self.pool.execute(f"DELETE FROM {self.table} WHERE {' AND '.join(f'{c} = ${i}' for i, c in enums)}", *opt.values())
 
+    async def ncdelete(self):
+        await self.pool.execute(f"DELETE FROM {self.table}")
+
 
 
     async def add(self, **opt):
         one_column = f"{list(opt.keys())[0]} = array_append({list(opt.keys())[0]}, $1)"
-        print(one_column)
         enums = enumerate(opt.keys(), 1)
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1) 
-        print('無し' if not columns else f'カラム: {columns}')
 
         if not columns:
             return await self.pool.execute(f'UPDATE {self.table} SET {one_column}', *opt.values())
@@ -126,4 +134,7 @@ class Pg:
         enums = enumerate(opt.keys(), 1)
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1)
 
+        if not columns:
+            return await self.pool.execute(f'UPDATE {self.table} SET {one_column}', *opt.values())
+
         await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
\ No newline at end of file
